@@ -7,6 +7,8 @@ from deserialize.decorators.downcasting import (
     _get_downcast_field,
     downcast_identifier,
     _get_downcast_class,
+    allow_downcast_fallback,
+    _allows_downcast_fallback,
 )
 from deserialize.decorators.ignore import ignore, _should_ignore
 from deserialize.decorators.key import key, _get_key
